@@ -37,7 +37,8 @@
 
 import readline
 import argparse
-import os, six, sys
+import os
+import sys
 
 from pykickstart.i18n import _
 from pykickstart.errors import KickstartError, KickstartVersionError
@@ -95,8 +96,33 @@ class KickstartCompleter(object):
         if cStr.startswith(".") or not hasattr(cObj, "op"):
             return
 
-        for opt in cObj.op.option_list:
-            self.commands[cStr] += opt._short_opts + opt._long_opts
+        for opt in cObj.op._actions:
+            self.commands[cStr] += opt.option_strings
+
+    def _init_matches(self, origline, begin, end):
+        beingCompleted = origline[begin:end]
+        parts = origline.split()
+
+        if not parts:
+            # Everything's a match for an empty string.
+            self.currentCandidates = sorted(self.commands.keys())
+        else:
+            try:
+                # Ignore leading whitespace when trying to figure out
+                # completions for a kickstart command.
+                if begin == 0 or origline[:begin].strip() == "":
+                    # first word
+                    candidates = self.commands.keys()
+                else:
+                    # later word
+                    candidates = self.commands[parts[0]]
+
+                if beingCompleted:
+                    self.currentCandidates = [w for w in candidates if w.startswith(beingCompleted)]
+                else:
+                    self.currentCandidates = list(candidates)
+            except (KeyError, IndexError):
+                self.currentCandidates = []
 
     def complete(self, _text, state):
         response = None
@@ -107,29 +133,7 @@ class KickstartCompleter(object):
             begin = readline.get_begidx()
             end = readline.get_endidx()
 
-            beingCompleted = origline[begin:end]
-            parts = origline.split()
-
-            if not parts:
-                # Everything's a match for an empty string.
-                self.currentCandidates = sorted(self.commands.keys())
-            else:
-                try:
-                    # Ignore leading whitespace when trying to figure out
-                    # completions for a kickstart command.
-                    if begin == 0 or origline[:begin].strip() == "":
-                        # first word
-                        candidates = self.commands.keys()
-                    else:
-                        # later word
-                        candidates = self.commands[parts[0]]
-
-                    if beingCompleted:
-                        self.currentCandidates = [w for w in candidates if w.startswith(beingCompleted)]
-                    else:
-                        self.currentCandidates = list(candidates)
-                except (KeyError, IndexError):
-                    self.currentCandidates = []
+            self._init_matches(origline, begin, end)
 
         try:
             response = self.currentCandidates[state]
@@ -138,7 +142,7 @@ class KickstartCompleter(object):
 
         return response
 
-def main():
+def main(argv=None):
 
     ##
     ## OPTION PROCESSING
@@ -152,7 +156,7 @@ def main():
     op.add_argument("-v", "--version", dest="version", default=DEVEL,
                     help=_("version of kickstart syntax to validate against"))
 
-    opts = op.parse_args(sys.argv[1:])
+    opts = op.parse_args(argv)
 
     ##
     ## SETTING UP PYKICKSTART
@@ -162,7 +166,7 @@ def main():
         kshandler = makeVersion(opts.version)
     except KickstartVersionError:
         print(_("The version %s is not supported by pykickstart") % opts.version)
-        sys.exit(1)
+        return 1
 
     ksparser = KickstartParser(kshandler, followIncludes=True, errorsAreFatal=False)
 
@@ -199,7 +203,7 @@ def main():
 
     while True:
         try:
-            line = six.moves.input("ks> ")  # pylint: disable=no-member
+            line = input("ks> ")
         except EOFError:
             # ^D was hit, time to quit.
             break
@@ -236,5 +240,7 @@ def main():
     else:
         print("\n" + str(ksparser.handler))
 
+    return 0
+
 if __name__ == "__main__":
-    main()
+    sys.exit(main())
